if RazerNaga == nil then RazerNaga = {} end

local debug = false
local alpha = false

local T = LibStub( "WAR-AceLocale-3.0" ) : GetLocale( "RazerNaga", debug )

--
-- The numerical order of these modifiers is important.  Add new ones to the end
--
RazerNaga.MODIFIER_UNASSIGNED	= 1		-- This entry is not presented to the user and is used when the modifier is auto cleared
RazerNaga.MODIFIER_NONE			= 2
RazerNaga.MODIFIER_ALT			= 3
RazerNaga.MODIFIER_CTRL			= 4 
RazerNaga.MODIFIER_SHIFT		= 5

RazerNaga.MODIFIER =
{
	[RazerNaga.MODIFIER_UNASSIGNED]		= 
	{ 
		text	= T[""], 		
		button 	= 0,
		modifier = RazerNaga.MODIFIER_UNASSIGNED,
		update 	= function( id ) RazerNaga.UpdateModifier( id, RazerNaga.MODIFIER_UNASSIGNED ) end
	},
	
	[RazerNaga.MODIFIER_NONE]		= 
	{ 
		text	= GetString( StringTables.Default.LABEL_NONE ), 		
		button 	= 0,
		modifier = RazerNaga.MODIFIER_NONE,
		update 	= function( id ) RazerNaga.UpdateModifier( id, RazerNaga.MODIFIER_NONE ) end
	},
	
	[RazerNaga.MODIFIER_ALT]		= 
	{ 
		--text	= T["ALT key"], 
		text 	= KeyUtils.GetBindingName( { 56 }, 1 ),		
		button 	= 56,
		modifier = RazerNaga.MODIFIER_ALT,
		update 	= function( id ) RazerNaga.UpdateModifier( id, RazerNaga.MODIFIER_ALT ) end
	},
	[RazerNaga.MODIFIER_CTRL]		= 
	{ 
		--text	= T["CTRL key"], 		
		text 	= KeyUtils.GetBindingName( { 29 }, 1 ),
		button 	= 29,
		modifier = RazerNaga.MODIFIER_CTRL,
		update 	= function( id ) RazerNaga.UpdateModifier( id, RazerNaga.MODIFIER_CTRL ) end
	},
	[RazerNaga.MODIFIER_SHIFT]		= 
	{ 
		--text	= T["SHIFT key"],
		text 	= KeyUtils.GetBindingName( { 42 }, 1 ),	
		button 	= 42,
		modifier = RazerNaga.MODIFIER_SHIFT,
		update 	= function( id ) RazerNaga.UpdateModifier( id, RazerNaga.MODIFIER_SHIFT ) end
	},
}

RazerNaga.MODIFIER_MENU = {}
RazerNaga.MODIFIER_MENU[1] = RazerNaga.MODIFIER_NONE
RazerNaga.MODIFIER_MENU[2] = RazerNaga.MODIFIER_ALT
RazerNaga.MODIFIER_MENU[3] = RazerNaga.MODIFIER_CTRL
RazerNaga.MODIFIER_MENU[4] = RazerNaga.MODIFIER_SHIFT
RazerNaga.MODIFIER_MENU[5] = RazerNaga.MODIFIER_ALT_CTRL
RazerNaga.MODIFIER_MENU[6] = RazerNaga.MODIFIER_ALT_SHIFT
RazerNaga.MODIFIER_MENU[7] = RazerNaga.MODIFIER_CTRL_SHIFT

--
-- The numerical order of these modes is important.  Add new ones to the end
--
RazerNaga.MODE_BASIC	= 1
RazerNaga.MODE_ADVANCED	= 2

RazerNaga.MODES = 
{
	[RazerNaga.MODE_BASIC]		= { desc=T["Basic"] 	},
	[RazerNaga.MODE_ADVANCED]	= { desc=T["Advanced"] 	}
}

--
-- The numerical order of these modes is important.  Add new ones to the end
--
RazerNaga.ORIENTATION_FOUR_BY_THREE			= 1
RazerNaga.ORIENTATION_THREE_BY_FOUR 		= 2
RazerNaga.ORIENTATION_ONE_BY_TWELVE 		= 3
RazerNaga.ORIENTATION_TWELVE_BY_ONE 		= 4
RazerNaga.ORIENTATION_SIX_BY_TWO	 		= 5
RazerNaga.ORIENTATION_TWO_BY_SIX	 		= 6

--
-- Orientation configuration information
--
RazerNaga.ORIENTATION =
{
	[RazerNaga.ORIENTATION_FOUR_BY_THREE] =
	{
		text 	= T["4 x 3"],
		columns	= 4,
		orientation = RazerNaga.ORIENTATION_FOUR_BY_THREE,
		update 	= function( id ) RazerNaga.UpdateOrientation( id, RazerNaga.ORIENTATION_FOUR_BY_THREE ) end
	},
	[RazerNaga.ORIENTATION_THREE_BY_FOUR] =
	{
		text 	= T["3 x 4"],
		columns	= 3,
		orientation = RazerNaga.ORIENTATION_THREE_BY_FOUR,
		update 	= function( id ) RazerNaga.UpdateOrientation( id, RazerNaga.ORIENTATION_THREE_BY_FOUR ) end
	},
	[RazerNaga.ORIENTATION_ONE_BY_TWELVE] =
	{
		text 	= T["1 x 12"],
		columns	= 1,
		orientation = RazerNaga.ORIENTATION_ONE_BY_TWELVE,
		update 	= function( id ) RazerNaga.UpdateOrientation( id, RazerNaga.ORIENTATION_ONE_BY_TWELVE ) end
	},
	[RazerNaga.ORIENTATION_TWELVE_BY_ONE] =
	{
		text 	= T["12 x 1"],
		columns	= 12,
		orientation = RazerNaga.ORIENTATION_TWELVE_BY_ONE,
		update 	= function( id ) RazerNaga.UpdateOrientation( id, RazerNaga.ORIENTATION_TWELVE_BY_ONE ) end
	},
	[RazerNaga.ORIENTATION_SIX_BY_TWO] =
	{
		text 	= T["6 x 2"],
		columns	= 6,
		orientation = RazerNaga.ORIENTATION_SIX_BY_TWO,
		update 	= function( id ) RazerNaga.UpdateOrientation( id, RazerNaga.ORIENTATION_SIX_BY_TWO ) end
	},
	[RazerNaga.ORIENTATION_TWO_BY_SIX] =
	{
		text 	= T["2 x 6"],
		columns	= 2,
		orientation = RazerNaga.ORIENTATION_TWO_BY_SIX,
		update 	= function( id ) RazerNaga.UpdateOrientation( id, RazerNaga.ORIENTATION_TWO_BY_SIX ) end
	},
}

-- This table determines the orientation menu layout.  Order is not important
RazerNaga.ORIENTATION_MENU = {}
RazerNaga.ORIENTATION_MENU[1] = RazerNaga.ORIENTATION_TWELVE_BY_ONE
RazerNaga.ORIENTATION_MENU[2] = RazerNaga.ORIENTATION_SIX_BY_TWO
RazerNaga.ORIENTATION_MENU[3] = RazerNaga.ORIENTATION_FOUR_BY_THREE
RazerNaga.ORIENTATION_MENU[4] = RazerNaga.ORIENTATION_THREE_BY_FOUR
RazerNaga.ORIENTATION_MENU[5] = RazerNaga.ORIENTATION_TWO_BY_SIX
RazerNaga.ORIENTATION_MENU[6] = RazerNaga.ORIENTATION_ONE_BY_TWELVE